@@ -10,7 +10,9 @@
 
 #if defined(__APPLE__)
 
+# undef ALIGNOF_MAX_ALIGN_T
 # undef SIZEOF_LONG
+# undef SIZEOF_LONG_DOUBLE
 # undef SIZEOF_PTHREAD_T
 # undef SIZEOF_SIZE_T
 # undef SIZEOF_TIME_T
@@ -23,6 +25,7 @@
 # undef DOUBLE_IS_BIG_ENDIAN_IEEE754
 # undef DOUBLE_IS_LITTLE_ENDIAN_IEEE754
 # undef HAVE_GCC_ASM_FOR_X87
+# undef HAVE_GCC_ASM_FOR_X64
 
 #    undef VA_LIST_IS_ARRAY
 #    if defined(__LP64__) && defined(__x86_64__)
@@ -63,7 +66,7 @@
 #    if defined(__LP64__)
      /* MacOSX 10.4 (the first release to support 64-bit code
       * at all) only supports 64-bit in the UNIX layer.
-      * Therefore surpress the toolbox-glue in 64-bit mode.
+      * Therefore suppress the toolbox-glue in 64-bit mode.
       */
 
     /* In 64-bit mode setpgrp always has no arguments, in 32-bit
@@ -80,22 +83,16 @@
 #define DOUBLE_IS_LITTLE_ENDIAN_IEEE754
 #endif /* __BIG_ENDIAN */
 
-#ifdef __i386__
+#if defined(__i386__) || defined(__x86_64__)
 # define HAVE_GCC_ASM_FOR_X87
+# define ALIGNOF_MAX_ALIGN_T 16
+# define HAVE_GCC_ASM_FOR_X64 1
+# define SIZEOF_LONG_DOUBLE 16
+#else
+# define ALIGNOF_MAX_ALIGN_T 8
+# define SIZEOF_LONG_DOUBLE 8
 #endif
 
-    /*
-     * The definition in pyconfig.h is only valid on the OS release
-     * where configure ran on and not necessarily for all systems where
-     * the executable can be used on.
-     *
-     * Specifically: OSX 10.4 has limited supported for '%zd', while
-     * 10.5 has full support for '%zd'. A binary built on 10.5 won't
-     * work properly on 10.4 unless we surpress the definition
-     * of PY_FORMAT_SIZE_T
-     */
-#undef  PY_FORMAT_SIZE_T
-
 
 #endif /* defined(_APPLE__) */
 
