@@ -3,14 +3,14 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_LONG': 4,
  'ALIGNOF_MAX_ALIGN_T': 8,
- 'ALIGNOF_SIZE_T': 8,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare -mieee',
+ 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/pkg/bin',
@@ -23,16 +23,16 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'alpha--netbsd',
+ 'BUILD_GNU_TYPE': 'm68k--netbsdelf',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare -mieee -DNDEBUG -O2 -mieee '
-           '-I/usr/include -I/usr/include/readline -I/usr/pkg/include -O2 '
-           '-mieee -I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-           '-O2 -mieee -I/usr/include -I/usr/include/readline '
-           '-I/usr/pkg/include',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+           '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+           '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
+           '-I/usr/include/readline -I/usr/pkg/include -O2 -fno-reorder-blocks '
+           '-I/usr/include -I/usr/include/readline -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -41,8 +41,8 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -mieee -I/usr/include -I/usr/include/readline '
-                     '-I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -fno-reorder-blocks -I/usr/include '
+                     '-I/usr/include/readline -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -58,13 +58,13 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--without-ensurepip' '--without-pymalloc' "
                 "'--with-readline=readline' '--prefix=/usr/pkg' "
-                "'--build=alpha--netbsd' '--host=alpha--netbsd' "
+                "'--build=m68k--netbsdelf' '--host=m68k--netbsdelf' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=alpha--netbsd' 'host_alias=alpha--netbsd' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work.alpha/.tools/bin/pkg-config' "
+                "'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work.m68k/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work.alpha/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work.alpha/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -mieee -I/usr/include "
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work.m68k/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work.m68k/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -fno-reorder-blocks -I/usr/include "
                 "-I/usr/include/readline -I/usr/pkg/include' "
                 "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
                 "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
@@ -73,9 +73,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4/coverage.info',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4/lcov-report',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -102,8 +102,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
  'DSYMUTIL': '',
  'DSYMUTIL_PATH': '',
  'DTRACE': '',
@@ -122,7 +122,7 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
+ 'FLOAT_WORDS_BIGENDIAN': 1,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
@@ -258,10 +258,10 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FUTIMES': 1,
  'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
- 'HAVE_GCC_ASM_FOR_MC68881': 0,
+ 'HAVE_GCC_ASM_FOR_MC68881': 1,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 0,
  'HAVE_GDBM_NDBM_H': 0,
@@ -329,7 +329,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -623,7 +623,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'alpha--netbsd',
+ 'HOST_GNU_TYPE': 'm68k--netbsdelf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -636,7 +636,10 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'c++ -pthread -shared',
+ 'LDCXXSHARED': 'c++ -pthread -shared -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+                '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+                '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
@@ -653,12 +656,14 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/pkg/lib/python3.12',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -mieee -DNDEBUG -O2 '
-                    '-mieee -I/usr/include -I/usr/include/readline '
-                    '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 -mieee '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-std=gnu11 -Wextra -Wno-unused-parameter '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                    '-fno-reorder-blocks -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                    '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
@@ -668,32 +673,35 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -mieee -DNDEBUG -O2 '
-                   '-mieee -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -O2 -mieee '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+                   '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+                   '-I/usr/pkg/include -std=gnu11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-std=gnu11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -fPIC -fPIC',
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
  'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
-                    '-mieee -DNDEBUG -O2 -mieee -I/usr/include '
-                    '-I/usr/include/readline -I/usr/pkg/include -O2 -mieee '
-                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                    '-O2 -mieee -I/usr/include -I/usr/include/readline '
-                    '-I/usr/pkg/include -std=gnu11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                    '-fno-reorder-blocks -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-fno-reorder-blocks -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                    '-Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
                     '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
@@ -910,8 +918,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_CFLAGS': '-DUSE_NDBM',
  'MODULE__DBM_LDFLAGS': '',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
-                           '-DANSI=1 -DHAVE_UINT128_T=1',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
+                           '-DANSI=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                          'Modules/_decimal/libmpdec/libmpdec.a',
  'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -972,14 +980,14 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I./Modules/_sqlite',
+ 'MODULE__SQLITE3_CFLAGS': '-I/usr/pkg/include -I./Modules/_sqlite',
  'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h '
                          './Modules/_sqlite/cursor.h '
                          './Modules/_sqlite/microprotocols.h '
                          './Modules/_sqlite/module.h '
                          './Modules/_sqlite/prepare_protocol.h '
                          './Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
- 'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
+ 'MODULE__SQLITE3_LDFLAGS': '-Wl,-R/usr/pkg/lib -L/usr/pkg/lib -lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '-I/usr/include',
@@ -1021,8 +1029,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -mieee -I/usr/include -I/usr/include/readline '
-        '-I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -fno-reorder-blocks -I/usr/include '
+        '-I/usr/include/readline -I/usr/pkg/include',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1057,11 +1065,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -mieee '
-                             '-DNDEBUG -O2 -mieee -I/usr/include '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                             '-fno-reorder-blocks -I/usr/include '
                              '-I/usr/include/readline -I/usr/pkg/include -O2 '
-                             '-mieee -I/usr/include -I/usr/include/readline '
-                             '-I/usr/pkg/include -O2 -mieee -I/usr/include '
+                             '-fno-reorder-blocks -I/usr/include '
+                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                             '-fno-reorder-blocks -I/usr/include '
                              '-I/usr/include/readline -I/usr/pkg/include '
                              '-std=gnu11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
@@ -1072,28 +1081,29 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I/usr/include/readline -I/usr/pkg/include '
                              '-I/usr/include -I/usr/include/readline '
                              '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -mieee -DNDEBUG -O2 -mieee '
-              '-I/usr/include -I/usr/include/readline -I/usr/pkg/include -O2 '
-              '-mieee -I/usr/include -I/usr/include/readline '
-              '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-              '-I/usr/include/readline -I/usr/pkg/include',
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+              '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+              '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
+              '-I/usr/include/readline -I/usr/pkg/include -O2 '
+              '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+              '-I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -mieee -DNDEBUG -O2 '
-                   '-mieee -I/usr/include -I/usr/include/readline '
-                   '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -O2 -mieee '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+                   '-I/usr/pkg/include -O2 -fno-reorder-blocks -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                   '-fno-reorder-blocks -I/usr/include -I/usr/include/readline '
+                   '-I/usr/pkg/include -std=gnu11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
-                   '-std=gnu11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -I/usr/include '
-                   '-I/usr/include/readline -I/usr/pkg/include -fPIC '
-                   '-DPy_BUILD_CORE',
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
@@ -1113,17 +1123,18 @@ build_time_vars = {'ABIFLAGS': '',
                      '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 0,
- 'PY_SQLITE_HAVE_SERIALIZE': 0,
+ 'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -mieee -DNDEBUG '
-                        '-O2 -mieee -I/usr/include -I/usr/include/readline '
-                        '-I/usr/pkg/include -O2 -mieee -I/usr/include '
-                        '-I/usr/include/readline -I/usr/pkg/include -O2 -mieee '
-                        '-I/usr/include -I/usr/include/readline '
-                        '-I/usr/pkg/include -std=gnu11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                        '-fno-reorder-blocks -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                        '-fno-reorder-blocks -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                        '-fno-reorder-blocks -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                        '-Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include -I/usr/include/readline '
@@ -1140,7 +1151,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1186,18 +1197,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-312',
@@ -1218,10 +1229,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1249,10 +1260,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work.alpha/Python-3.12.4',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.6',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
