@@ -3,9 +3,9 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 4,
- 'ALIGNOF_MAX_ALIGN_T': 8,
- 'ALIGNOF_SIZE_T': 4,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_MAX_ALIGN_T': 16,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -16,22 +16,22 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/pkg/bin',
  'BINLIBDEST': '/usr/pkg/lib/python3.12',
  'BLDLIBRARY': '-L. -lpython3.12',
- 'BLDSHARED': 'gcc -pthread -shared -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
-              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-              '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
-              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-              '-Wl,-R/usr/X11R7/lib',
+ 'BLDSHARED': 'gcc -pthread -shared -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+              '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+              '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+              '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'powerpc--netbsd',
+ 'BUILD_GNU_TYPE': 'sparc64--netbsd',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-           '-I/usr/include -I/usr/pkg/include',
+           '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
+           '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
+           '-I/usr/include/readline -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -40,41 +40,45 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/include/readline '
+                     '-I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
- 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/include/readline '
+                       '-I/usr/pkg/include',
+ 'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--without-ensurepip' '--without-pymalloc' "
-                "'--prefix=/usr/pkg' '--build=powerpc--netbsd' "
-                "'--host=powerpc--netbsd' '--mandir=/usr/pkg/man' "
-                "'--enable-option-checking=yes' 'build_alias=powerpc--netbsd' "
-                "'host_alias=powerpc--netbsd' "
-                "'PKG_CONFIG=/usr/pkgsrc/lang/python312/work/.tools/bin/pkg-config' "
+                "'--with-readline=readline' '--prefix=/usr/pkg' "
+                "'--build=sparc64--netbsd' '--host=sparc64--netbsd' "
+                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
+                "'build_alias=sparc64--netbsd' 'host_alias=sparc64--netbsd' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work.sparc64/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python312/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python312/work/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
-                "'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
-                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
-                "'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work.sparc64/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work.sparc64/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/include/readline "
+                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
+                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+                "-Wl,-R/usr/X11R7/lib' 'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
+                "-I/usr/include/readline -I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/pkgsrc/lang/python312/work/Python-3.12.2/coverage.info',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python312/work/Python-3.12.2/lcov-report',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
+             '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
@@ -255,7 +259,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 0,
  'HAVE_GDBM_NDBM_H': 0,
@@ -323,7 +327,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 1,
  'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
@@ -425,7 +429,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
- 'HAVE_READLINE_READLINE_H': 0,
+ 'HAVE_READLINE_READLINE_H': 1,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -434,11 +438,11 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
- 'HAVE_RL_COMPDISP_FUNC_T': 1,
+ 'HAVE_RL_COMPDISP_FUNC_T': 0,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
- 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
+ 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_RPC_RPC_H': 1,
@@ -617,7 +621,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'powerpc--netbsd',
+ 'HOST_GNU_TYPE': 'sparc64--netbsd',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -630,61 +634,71 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'c++ -pthread -shared',
- 'LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-            '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-            '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDCXXSHARED': 'c++ -pthread -shared -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+                '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+                '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+            '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib '
+            '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+            '-Wl,-R/usr/X11R7/lib',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
-             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-             '-Wl,-R/usr/X11R7/lib -Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib '
-             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-             '-Wl,-R/usr/X11R7/lib',
+ 'LDSHARED': 'gcc -pthread -shared -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+             '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
+             '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+             '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDVERSION': '3.12',
  'LIBC': '',
  'LIBDEST': '/usr/pkg/lib/python3.12',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
-                    '-std=gnu11 -Wextra -Wno-unused-parameter '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-O2 -I/usr/include -I/usr/include/readline '
+                    '-I/usr/pkg/include -O2 -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                    '-Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                    '-I/usr/pkg/include -fPIC -fPIC',
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
-                   '-std=gnu11 -Wextra -Wno-unused-parameter '
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-O2 -I/usr/include -I/usr/include/readline '
+                   '-I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                   '-Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
-                   '-fPIC',
+                   '-I/usr/include/readline -I/usr/pkg/include -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
  'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+ 'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
+                    '-DHAVE_UINT128_T=1 -fno-strict-overflow -Wsign-compare '
+                    '-DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
+                    '-I/usr/pkg/include -O2 -I/usr/include '
+                    '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                    '-I/usr/pkg/include -fPIC -fPIC',
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                    '-fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -800,9 +814,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '',
  'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
  'MODULE_PYEXPAT_STATE': 'yes',
- 'MODULE_READLINE_CFLAGS': '-I/usr/pkg/include',
- 'MODULE_READLINE_LDFLAGS': '-Wl,-R/usr/pkg/lib -L/usr/pkg/lib -lreadline '
-                            '-ltermcap',
+ 'MODULE_READLINE_CFLAGS': '',
+ 'MODULE_READLINE_LDFLAGS': '-lreadline',
  'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
  'MODULE_SELECT_STATE': 'yes',
@@ -898,8 +911,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_CFLAGS': '-DUSE_NDBM',
  'MODULE__DBM_LDFLAGS': '',
  'MODULE__DBM_STATE': 'yes',
- 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 '
-                           '-DANSI=1',
+ 'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
+                           '-DANSI=1 -DHAVE_UINT128_T=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
                          'Modules/_decimal/libmpdec/libmpdec.a',
  'MODULE__DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -922,7 +935,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LOCALE_LDFLAGS': '',
  'MODULE__LSPROF_STATE': 'yes',
  'MODULE__LZMA_CFLAGS': '',
- 'MODULE__LZMA_LDFLAGS': '-Wl,-R/usr/lib -llzma',
+ 'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
  'MODULE__MD5_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
@@ -960,14 +973,14 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I./Modules/_sqlite',
+ 'MODULE__SQLITE3_CFLAGS': '-I/usr/pkg/include -I./Modules/_sqlite',
  'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h '
                          './Modules/_sqlite/cursor.h '
                          './Modules/_sqlite/microprotocols.h '
                          './Modules/_sqlite/module.h '
                          './Modules/_sqlite/prepare_protocol.h '
                          './Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
- 'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
+ 'MODULE__SQLITE3_LDFLAGS': '-Wl,-R/usr/pkg/lib -L/usr/pkg/lib -lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '-I/usr/include',
@@ -1009,7 +1022,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/include/readline '
+        '-I/usr/pkg/include',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1045,65 +1059,76 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
-                             '-Wextra -Wno-unused-parameter '
+                             '-I/usr/include -I/usr/include/readline '
+                             '-I/usr/pkg/include -O2 -I/usr/include '
+                             '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/include/readline '
+                             '-I/usr/pkg/include -std=gnu11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/pkg/include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-I./Include -I/usr/include '
+                             '-I/usr/include/readline -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/include/readline '
+                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-              '-I/usr/include -I/usr/pkg/include',
+              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
+              '-I/usr/include/readline -I/usr/pkg/include -O2 -I/usr/include '
+              '-I/usr/include/readline -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
-                   '-std=gnu11 -Wextra -Wno-unused-parameter '
+                   '-I/usr/include -I/usr/include/readline -I/usr/pkg/include '
+                   '-O2 -I/usr/include -I/usr/include/readline '
+                   '-I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -std=gnu11 '
+                   '-Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
+                   '-I/usr/include/readline -I/usr/pkg/include -I/usr/include '
+                   '-I/usr/include/readline -I/usr/pkg/include -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                    '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                    '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-                '-I/usr/include -I/usr/pkg/include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/include/readline '
+                '-I/usr/pkg/include -I/usr/include -I/usr/include/readline '
+                '-I/usr/pkg/include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
- 'PY_LDFLAGS': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-               '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
-               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+               '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib -L/usr/lib '
+               '-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+               '-L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_LDFLAGS_NODIST': '',
- 'PY_LDFLAGS_NOLTO': '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+ 'PY_LDFLAGS_NOLTO': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
-                     '-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                      '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 0,
- 'PY_SQLITE_HAVE_SERIALIZE': 0,
+ 'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/include -I/usr/include/readline '
                         '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -O2 '
+                        '-I/usr/include -I/usr/include/readline '
                         '-I/usr/pkg/include -std=gnu11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/include -I/usr/pkg/include -fPIC',
+                        '-I./Include -I/usr/include -I/usr/include/readline '
+                        '-I/usr/pkg/include -I/usr/include '
+                        '-I/usr/include/readline -I/usr/pkg/include -fPIC',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1115,7 +1140,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python312/work/Python-3.12.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1161,18 +1186,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-312',
@@ -1193,10 +1218,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python312/work/Python-3.12.2 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python312/work/Python-3.12.2 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1226,8 +1251,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/pkgsrc/lang/python312/work/Python-3.12.2',
- 'abs_srcdir': '/usr/pkgsrc/lang/python312/work/Python-3.12.2',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work.sparc64/Python-3.12.6',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
