@@ -132,7 +132,7 @@ def v4_int_to_packed(address):
 
     """
     try:
-        return address.to_bytes(4, 'big')
+        return address.to_bytes(4)  # big endian
     except OverflowError:
         raise ValueError("Address negative or too large for IPv4")
 
@@ -148,7 +148,7 @@ def v6_int_to_packed(address):
 
     """
     try:
-        return address.to_bytes(16, 'big')
+        return address.to_bytes(16)  # big endian
     except OverflowError:
         raise ValueError("Address negative or too large for IPv6")
 
@@ -734,7 +734,7 @@ class _BaseNetwork(_IPAddressBase):
             return NotImplemented
 
     def __hash__(self):
-        return hash((int(self.network_address), int(self.netmask)))
+        return hash(int(self.network_address) ^ int(self.netmask))
 
     def __contains__(self, other):
         # always false if one is v4 and the other is v6.
@@ -1077,15 +1077,20 @@ class _BaseNetwork(_IPAddressBase):
 
     @property
     def is_private(self):
-        """Test if this address is allocated for private networks.
+        """Test if this network belongs to a private range.
 
         Returns:
-            A boolean, True if the address is reserved per
+            A boolean, True if the network is reserved per
             iana-ipv4-special-registry or iana-ipv6-special-registry.
 
         """
-        return (self.network_address.is_private and
-                self.broadcast_address.is_private)
+        return any(self.network_address in priv_network and
+                   self.broadcast_address in priv_network
+                   for priv_network in self._constants._private_networks) and all(
+                    self.network_address not in network and
+                    self.broadcast_address not in network
+                    for network in self._constants._private_networks_exceptions
+                )
 
     @property
     def is_global(self):
@@ -1122,6 +1127,15 @@ class _BaseNetwork(_IPAddressBase):
         return (self.network_address.is_loopback and
                 self.broadcast_address.is_loopback)
 
+
+class _BaseConstants:
+
+    _private_networks = []
+
+
+_BaseNetwork._constants = _BaseConstants
+
+
 class _BaseV4:
 
     """Base IPv4 object.
@@ -1294,7 +1308,7 @@ class IPv4Address(_BaseV4, _BaseAddress):
         # Constructing from a packed address
         if isinstance(address, bytes):
             self._check_packed_address(address, 4)
-            self._ip = int.from_bytes(address, 'big')
+            self._ip = int.from_bytes(address)  # big endian
             return
 
         # Assume input argument to be string or any object representation
@@ -1591,6 +1605,7 @@ class _IPv4Constants:
 
 
 IPv4Address._constants = _IPv4Constants
+IPv4Network._constants = _IPv4Constants
 
 
 class _BaseV6:
@@ -1649,18 +1664,8 @@ class _BaseV6:
         """
         if not ip_str:
             raise AddressValueError('Address cannot be empty')
-        if len(ip_str) > 45:
-            shorten = ip_str
-            if len(shorten) > 100:
-                shorten = f'{ip_str[:45]}({len(ip_str)-90} chars elided){ip_str[-45:]}'
-            raise AddressValueError(f"At most 45 characters expected in "
-                                    f"{shorten!r}")
 
-        # We want to allow more parts than the max to be 'split'
-        # to preserve the correct error message when there are
-        # too many parts combined with '::'
-        _max_parts = cls._HEXTET_COUNT + 1
-        parts = ip_str.split(':', maxsplit=_max_parts)
+        parts = ip_str.split(':')
 
         # An IPv6 address needs at least 2 colons (3 parts).
         _min_parts = 3
@@ -1680,6 +1685,7 @@ class _BaseV6:
         # An IPv6 address can't have more than 8 colons (9 parts).
         # The extra colon comes from using the "::" notation for a single
         # leading or trailing zero part.
+        _max_parts = cls._HEXTET_COUNT + 1
         if len(parts) > _max_parts:
             msg = "At most %d colons permitted in %r" % (_max_parts-1, ip_str)
             raise AddressValueError(msg)
@@ -1951,49 +1957,8 @@ class IPv6Address(_BaseV6, _BaseAddress):
 
         self._ip = self._ip_int_from_string(addr_str)
 
-    def _explode_shorthand_ip_string(self):
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is None:
-            return super()._explode_shorthand_ip_string()
-        prefix_len = 30
-        raw_exploded_str = super()._explode_shorthand_ip_string()
-        return f"{raw_exploded_str[:prefix_len]}{ipv4_mapped!s}"
-
-    def _reverse_pointer(self):
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is None:
-            return super()._reverse_pointer()
-        prefix_len = 30
-        raw_exploded_str = super()._explode_shorthand_ip_string()[:prefix_len]
-        # ipv4 encoded using hexadecimal nibbles instead of decimals
-        ipv4_int = ipv4_mapped._ip
-        reverse_chars = f"{raw_exploded_str}{ipv4_int:008x}"[::-1].replace(':', '')
-        return '.'.join(reverse_chars) + '.ip6.arpa'
-
-    def _ipv4_mapped_ipv6_to_str(self):
-        """Return convenient text representation of IPv4-mapped IPv6 address
-
-        See RFC 4291 2.5.5.2, 2.2 p.3 for details.
-
-        Returns:
-            A string, 'x:x:x:x:x:x:d.d.d.d', where the 'x's are the hexadecimal values of
-            the six high-order 16-bit pieces of the address, and the 'd's are
-            the decimal values of the four low-order 8-bit pieces of the
-            address (standard IPv4 representation) as defined in RFC 4291 2.2 p.3.
-
-        """
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is None:
-            raise AddressValueError("Can not apply to non-IPv4-mapped IPv6 address %s" % str(self))
-        high_order_bits = self._ip >> 32
-        return "%s:%s" % (self._string_from_ip_int(high_order_bits), str(ipv4_mapped))
-
     def __str__(self):
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is None:
-            ip_str = super().__str__()
-        else:
-            ip_str = self._ipv4_mapped_ipv6_to_str()
+        ip_str = super().__str__()
         return ip_str + '%' + self._scope_id if self._scope_id else ip_str
 
     def __hash__(self):
@@ -2007,6 +1972,9 @@ class IPv6Address(_BaseV6, _BaseAddress):
             return False
         return self._scope_id == getattr(other, '_scope_id', None)
 
+    def __reduce__(self):
+        return (self.__class__, (str(self),))
+
     @property
     def scope_id(self):
         """Identifier of a particular zone of the address's scope.
@@ -2033,9 +2001,6 @@ class IPv6Address(_BaseV6, _BaseAddress):
             See RFC 2373 2.7 for details.
 
         """
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is not None:
-            return ipv4_mapped.is_multicast
         return self in self._constants._multicast_network
 
     @property
@@ -2047,9 +2012,6 @@ class IPv6Address(_BaseV6, _BaseAddress):
             reserved IPv6 Network ranges.
 
         """
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is not None:
-            return ipv4_mapped.is_reserved
         return any(self in x for x in self._constants._reserved_networks)
 
     @property
@@ -2060,9 +2022,6 @@ class IPv6Address(_BaseV6, _BaseAddress):
             A boolean, True if the address is reserved per RFC 4291.
 
         """
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is not None:
-            return ipv4_mapped.is_link_local
         return self in self._constants._linklocal_network
 
     @property
@@ -2119,9 +2078,6 @@ class IPv6Address(_BaseV6, _BaseAddress):
         ``is_global`` has value opposite to :attr:`is_private`, except for the ``100.64.0.0/10``
         IPv4 range where they are both ``False``.
         """
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is not None:
-            return ipv4_mapped.is_global
         return not self.is_private
 
     @property
@@ -2133,9 +2089,6 @@ class IPv6Address(_BaseV6, _BaseAddress):
             RFC 2373 2.5.2.
 
         """
-        ipv4_mapped = self.ipv4_mapped
-        if ipv4_mapped is not None:
-            return ipv4_mapped.is_unspecified
         return self._ip == 0
 
     @property
@@ -2379,8 +2332,6 @@ class _IPv6Constants:
         IPv6Network('2001:db8::/32'),
         # IANA says N/A, let's consider it not globally reachable to be safe
         IPv6Network('2002::/16'),
-        # RFC 9637: https://www.rfc-editor.org/rfc/rfc9637.html#section-6-2.2
-        IPv6Network('3fff::/20'),
         IPv6Network('fc00::/7'),
         IPv6Network('fe80::/10'),
         ]
@@ -2409,3 +2360,4 @@ class _IPv6Constants:
 
 
 IPv6Address._constants = _IPv6Constants
+IPv6Network._constants = _IPv6Constants
